#!/usr/bin/python
# -*- coding: utf-8 -*-

# pyremotecv - remotecv client for python
# https://github.com/globocom/pyremotecv/wiki

# Licensed under the MIT license: 
# http://www.opensource.org/licenses/mit-license
# Copyright (c) 2012 globo.com timehome@corp.globo.com


# version is here for people to query for the library version upon install
from pyremotecv.version import version, Version, __version__

class PyRemoteCV:

    @classmethod
    def init_queue(cls):
        from pyremotecv.unique_queue import UniqueQueue
        cls.queue = UniqueQueue()

    @classmethod
    def async_detect(cls, class_name, queue_name, args=[], key=None):
        if not cls.queue:
            cls.init_queue()
        cls.queue.enqueue_unique_from_string(class_name, queue_name,
                args=args,
                key=key)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# pyremotecv - remotecv client for python
# https://github.com/globocom/pyremotecv/wiki

# Licensed under the MIT license: 
# http://www.opensource.org/licenses/mit-license
# Copyright (c) 2012 globo.com timehome@corp.globo.com

from setuptools import setup, find_packages
from pyremotecv.version import version

description = "pyremotecv is a client library for remotecv (https://github.com/globocom/remotecv/wiki)."

setup(
    name = 'pyremotecv',
    version = version,
    description = description,
    long_description = description,
    keywords = 'facial feature detection opencv remote zeromq socket',
    author = 'Time Home',
    author_email = 'timehome@corp.globo.com',
    url = 'https://github.com/globocom/pyremotecv',
    license = 'MIT',
    classifiers = ['Development Status :: 3 - Alpha',
                   'Intended Audience :: Developers',
                   'License :: OSI Approved :: MIT License',
                   'Natural Language :: English',
                   'Operating System :: MacOS',
                   'Operating System :: POSIX :: Linux',
                   'Programming Language :: Python :: 2.6',
    ],

    packages = find_packages(),

    install_requires=[
        "pyres>=1.1,<1.2"
    ],

)


